@@ -22,12 +22,24 @@ def pypi():
     run('python setup.py bdist_wheel')
 
 
+@task
+def pypi_test():
+    run('python setup.py sdist -r test')
+    run('python setup.py bdist_wheel -r test')
+
+
 @task
 def pypi_upload():
     run('python setup.py sdist upload')
     run('python setup.py bdist_wheel upload')
 
 
+@task
+def pypi_test_upload():
+    run('python setup.py sdist upload -r test')
+    run('python setup.py bdist_wheel upload -r test')
+
+
 @task
 def test():
     run('py.test '
